@@ -1,8 +1,8 @@
 from atelier.fablib import *
-setup_from_project('lino')
+setup_from_fabfile(globals(), 'lino')
 
 env.languages = "en de fr et nl pt-br es".split()
-env.tolerate_sphinx_warnings = True
+# env.tolerate_sphinx_warnings = True
 
 add_demo_database('lino.projects.docs.settings.demo')
 add_demo_database('lino.projects.min1.settings.demo')
@@ -15,4 +15,4 @@ add_demo_database('lino.projects.events.settings')
 
 env.revision_control_system = 'git'
 
-env.apidoc_exclude_pathnames = ['lino/projects']
+# env.apidoc_exclude_pathnames = ['lino/projects']
