@@ -6,25 +6,34 @@
     actions
     actors
     auth
+    boundaction
     choicelists
     constants
     dbtables
     dbutils
     ddh
+    elems
     fields
     frames
     inject
     kernel
+    keyboard
     layouts
     menus
     merge
     model
     perms
     plugin
+    renderer
     requests
     signals
     site_def
+    store
     tables
+    tablerequest
+    urls
+    utils
+    views
     web
     workflows
 
