@@ -1,10 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2014 Luc Saffre
+# Copyright 2009-2015 Luc Saffre
 # License: BSD (see file COPYING for details)
 
 """A collection of utilities which require Django settings to be
 importable.
 
+TODO: Merge this module and :mod:`lino.core.utils`.
+
 """
 
 from __future__ import unicode_literals
@@ -22,17 +24,20 @@ from django.db.models import loading
 from django.db.models.fields import FieldDoesNotExist
 from django.utils.importlib import import_module
 from django.utils.translation import ugettext as _
-from django.db.models.fields import NOT_PROVIDED
 
 from lino import AFTER17
-from lino.core.signals import pre_ui_update
 
-from django.core.validators import validate_email, ValidationError, URLValidator
+from django.core.validators import (
+    validate_email, ValidationError, URLValidator)
 
 validate_url = URLValidator()
 
 
 def is_valid_url(s):
+    """Returns `True` if the given string is a valid URL.  This calls
+Django's `URLValidator()`, but does not raise an exception.
+
+    """
     try:
         validate_url(s)
         return True
@@ -41,6 +46,10 @@ def is_valid_url(s):
 
 
 def is_valid_email(s):
+    """Returns `True` if the given string is a valid email.  This calls
+Django's `validate_email()`, but does not raise an exception.
+
+    """
     try:
         validate_email(s)
         return True
@@ -49,19 +58,18 @@ def is_valid_email(s):
 
 
 def is_devserver():
-    """
-    Returns True if we are running a development server.
+    """Returns `True` if this process is running as a development server.
     
-    Thanks to Aryeh Leib Taurog in 
-    `How can I tell whether my Django application is running on development server or not?
+    Thanks to Aryeh Leib Taurog in `How can I tell whether my Django
+    application is running on development server or not?
     <http://stackoverflow.com/questions/1291755>`_
     
     My additions:
     
-    - Added the `len(sys.argv) > 1` test because in a 
-      wsgi application the process is called without arguments.
+    - Added the `len(sys.argv) > 1` test because in a wsgi application
+      the process is called without arguments.
     - Not only for `runserver` but also for `testserver` and `test`.
-    
+
     """
     #~ print 20130315, sys.argv[1]
     return len(sys.argv) > 1 and sys.argv[1] in (
@@ -82,9 +90,9 @@ def obj2unicode(i):
 
 
 def obj2str(i, force_detailed=False):
-    """
-    Returns a human-readable ascii string representation of a model instance, 
-    even in some edge cases.
+    """Returns a human-readable ascii string representation of a model
+    instance, even in some edge cases.
+
     """
     if not isinstance(i, models.Model):
         if isinstance(i, long):
@@ -184,9 +192,6 @@ def inrange_filter(fld, rng, **kw):
     return Q(**kw)
 
 
-
-
-
 def babelkw(*args, **kw):
     return settings.SITE.babelkw(*args, **kw)
 
@@ -198,20 +203,19 @@ babel_values = babelkw  # old alias for backwards compatibility
 
 class UnresolvedModel:
 
-    """
-    This is the object returned by :func:`resolve_model` 
-    if the specified model is not installed.
+    """The object returned by :func:`resolve_model` if the specified model
+    is not installed.
     
-    We don't want resolve_model to raise an Exception because there are 
-    cases of :ref:`datamig` where it would disturb. 
-    Asking for a non-installed model is not a sin, but trying to use it is.
-    
-    I didn't yet bother very much about finding a way to make the 
-    model_spec appear in error messages such as
-    ``AttributeError: UnresolvedModel instance has no attribute '_meta'``.
-    Current workaround is to uncomment the ``print`` statement 
-    below in such situations...
+    We don't want :func:`resolve_model` to raise an Exception because
+    there are cases of :ref:`datamig` where it would disturb.  Asking
+    for a non-installed model is not a sin, but trying to use it is.
     
+    I didn't yet bother very much about finding a way to make the
+    `model_spec` appear in error messages such as
+    :message:`AttributeError: UnresolvedModel instance has no
+    attribute '_meta'`.  Current workaround is to uncomment the
+    ``print`` statement below in such situations...
+
     """
 
     def __init__(self, model_spec, app_label):
@@ -229,7 +233,7 @@ class UnresolvedModel:
 
 def resolve_model(model_spec, app_label=None, strict=False):
     """Return the class object of the specified model.  This works also in
-    combination with :attr:`ad.Site.override_modlib_models`, so you
+    combination with :attr:`lino.core.site_def.Site.override_modlib_models`, so you
     don't need to worry about where the real class definition is.
     
     Attention: this function **does not** trigger a loading of
@@ -320,9 +324,12 @@ def resolve_app(app_label, strict=False):
 def require_app_models(app_label):
     return resolve_app(app_label, True)
 
+
 def get_field(model, name):
-    '''Returns the field descriptor of the named field in the specified model.
-    '''
+    """Returns the field descriptor of the named field in the specified
+    model.
+
+    """
     for vf in model._meta.virtual_fields:
         if vf.name == name:
             return vf
@@ -338,7 +345,7 @@ class UnresolvedField(object):
     """
     Returned by :func:`resolve_field` if the specified field doesn't exist.
     This case happens when sphinx autodoc tries to import a module.
-    See ticket :doc:`/tickets/4`.
+    See ticket :srcref:`docs/tickets/4`.
     """
 
     def __init__(self, name):
@@ -347,9 +354,9 @@ class UnresolvedField(object):
 
 
 def resolve_field(name, app_label=None):
-    """
-    Returns the field descriptor specified by the string `name` which 
+    """Returns the field descriptor specified by the string `name` which
     should be either `model.field` or `app_label.model.field`.
+
     """
     l = name.split('.')
     if len(l) == 3:
@@ -376,10 +383,9 @@ def resolve_field(name, app_label=None):
 
 
 def navinfo(qs, elem):
-    """
-    Return a dict with navigation information for the given model 
-    instance `elem` within the given queryset. 
-    The dictionary contains the following keys:
+    """Return a dict with navigation information for the given model
+    instance `elem` within the given queryset.  The dictionary
+    contains the following keys:
     
     :recno:   row number (index +1) of elem in qs
     :first:   pk of the first element in qs (None if qs is empty)
@@ -387,8 +393,7 @@ def navinfo(qs, elem):
     :next:    pk of the next element in qs (None if qs is empty)
     :last:    pk of the last element in qs (None if qs is empty)
     :message: text "Row x of y" or "No navigation"
-    
-    
+
     """
     first = None
     prev = None
@@ -434,26 +439,3 @@ def navinfo(qs, elem):
         message=message)
 
 
-class ChangeWatcher(object):
-
-    """
-    Utility to watch changes and send pre_ui_update
-    """
-
-    def __init__(self, watched):
-        self.original_state = dict(watched.__dict__)
-        self.watched = watched
-        #~ self.is_new = is_new
-        #~ self.request
-
-    def is_dirty(self):
-        #~ if self.is_new:
-            #~ return True
-        for k, v in self.original_state.iteritems():
-            if v != self.watched.__dict__.get(k, NOT_PROVIDED):
-                return True
-        return False
-
-    def send_update(self, request):
-        #~ print "ChangeWatcher.send_update()", self.watched
-        pre_ui_update.send(sender=self, request=request)
