@@ -4,7 +4,7 @@
 
 """Defines extended field classes like :class:`RichTextField` and
 :class:`PercentageField`, utility functions like
-:func:`dd.fields_list`.
+:func:`fields_list`.
 
 """
 
@@ -23,15 +23,11 @@ from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes import generic
 from django.db.models.fields import NOT_PROVIDED
 
-
 from lino.core.dbutils import full_model_name
-from lino.core.dbutils import obj2str
-
 from lino.core.dbutils import resolve_field
-from lino.core.dbutils import resolve_model, UnresolvedModel
-#~ from lino.core.dbutils import is_installed_model_spec
+from lino.core.dbutils import resolve_model
 
-from lino.utils import IncompleteDate, d2iso
+from lino.utils.format_date import IncompleteDate
 from lino.utils import quantities
 
 
@@ -49,7 +45,7 @@ class RichTextField(models.TextField):
     """
     Only difference with Django's `models.TextField` is that you can
     specify a keyword argument `format` to
-    override the global :attr:`ad.Site.textfield_format`.
+    override the global :attr:`lino.core.site_def.Site.textfield_format`.
     """
 
     def __init__(self, *args, **kw):
@@ -225,7 +221,7 @@ class RemoteField(FakeField):
         #~ print 20120424, self.name
         #~ settings.SITE.register_virtual_field(self)
 
-        from lino.ui import store
+        from lino.core import store
         store.get_atomizer(self.rel, self, name)
 
     #~ def lino_resolve_type(self):
@@ -314,13 +310,21 @@ class VirtualGetter(object):
     def __call__(self, ar=None):
         return self.vf.value_from_object(self.instance, ar)
 
+    # def __get__(self, instance, owner):
+    #     return self.vf.value_from_object(instance, None)
+
     def __getattr__(self, name):
         obj = self.vf.value_from_object(self.instance, None)
         return getattr(obj, name)
 
 
 class VirtualField(FakeField):
-    "See :class:`dd.VirtualField`."
+    """
+    Represents a virtual field. Virtual fields are not stored in the
+    database, but computed each time they are read. Django doesn't see
+    them.
+
+    """
 
     def __init__(self, return_type, get):
         self.return_type = return_type  # a Django Field instance
@@ -386,7 +390,7 @@ class VirtualField(FakeField):
             setattr(self, k, getattr(self.return_type, k, None))
         #~ logger.info('20120831 VirtualField %s on %s',name,actor_or_model)
 
-        from lino.ui import store
+        from lino.core import store
         #~ self._lino_atomizer = store.create_field(self,self.name)
         store.get_atomizer(self.model, self, self.name)
 
@@ -452,6 +456,9 @@ class VirtualField(FakeField):
 
 
 def virtualfield(return_type):
+    """
+    Decorator to turn a method into a :class:`VirtualField`.
+    """
     def decorator(fn):
         return VirtualField(return_type, fn)
     return decorator
@@ -478,7 +485,9 @@ def constant():
 
 
 class RequestField(VirtualField):
-    "See :class:`dd.RequestField`."
+    """
+    A :class:`VirtualField` whose values are action request.
+    """
     def __init__(self, get, *args, **kw):
         kw.setdefault('max_length', 8)
         VirtualField.__init__(self, DisplayField(*args, **kw), get)
@@ -722,7 +731,7 @@ class IncompleteDateField(models.CharField):
     """
     A field that behaves like a DateField, but accepts
     incomplete dates represented using
-    :class:`lino.utils.IncompleteDate`.
+    :class:`lino.utils.format_date.IncompleteDate`.
     """
     __metaclass__ = models.SubfieldBase
 
@@ -775,7 +784,10 @@ class Dummy(object):
 
 
 class DummyField(FakeField):
-    "See :class:`dd.DummyField`."
+    """
+    Represents a field that doesn't exist in the current configuration but
+    might exist in other configurations.
+    """
     # choices = []
     # primary_key = False
 
@@ -809,7 +821,24 @@ class RecurrenceField(models.CharField):
 
 
 def fields_list(model, field_names):
-    "See :func:`dd.fields_list`."
+    """
+    Return a set with the names of the specified fields, checking whether
+    each of them exists.
+
+    **Arguments:** `model` is any subclass of `django.db.models.Model`. It
+    may be a string with the full name of a model
+    (e.g. ``"myapp.MyModel"``).  `field_names` is a single string with a
+    space-separated list of field names.
+
+    If one of the names refers to a :class:`DummyField`, this name
+    will be ignored silently.
+
+    For example if you have a model `MyModel` with two fields `foo` and
+    `bar`, then ``dd.fields_list(MyModel,"foo bar")`` will return
+    ``['foo','bar']`` and ``dd.fields_list(MyModel,"foo baz")`` will raise
+    an exception.
+
+    """
     lst = set()
     for name in field_names.split():
         e = model.get_data_elem(name)
@@ -822,7 +851,14 @@ def fields_list(model, field_names):
 
 
 def ForeignKey(othermodel, *args, **kw):
-    "See :class:`dd.ForeignKey`."
+    """A wrapper function which returns a Django `ForeignKey
+    <https://docs.djangoproject.com/en/dev/ref/models/fields/#foreignkey>`
+    field, with a subtle difference in the signature: it supports
+    `othermodel` being `None` or the name of some non-installed
+    model and returns a :class:`DummyField` in that case.  This
+    difference is useful when designing reusable models.
+
+    """
     if othermodel is None:
         return DummyField(othermodel, *args, **kw)
     if isinstance(othermodel, basestring):
@@ -832,8 +868,20 @@ def ForeignKey(othermodel, *args, **kw):
 
 
 class CustomField(object):
-    "See :class:`dd.CustomField`."
+    """
+    Mixin to create a custom field. It defines a single method
+    :meth:`dd.CustomField.create_layout_elem`
+
+    """
     def create_layout_elem(self, layout_handle, field, **kw):
+        """Instantiate and return some subclass of
+        :class:`lino.core.elems.LayoutElement` to be used in
+        `layout_handle`.
+
+        `self` and `field` are identical unless `self` is a
+        :class`RemoteField` or a :class:`VirtualField`.
+
+        """
         return None
 
 
