@@ -61,11 +61,11 @@ from lino.core import constants
 from lino.core import web
 from lino.core.signals import pre_ui_build, post_ui_build
 
-from lino.ui import store as ext_store
+from lino.core import store as ext_store
 
 from lino.core.dbutils import is_devserver
-from lino.ui.render import TextRenderer
-from lino.ui import views
+from lino.core.renderer import TextRenderer
+from lino.core import views
 
 from .plugin import Plugin
 from .ddh import DisableDeleteHandler
@@ -297,7 +297,9 @@ class Kernel(object):
         self.setup_workflows()
 
         for model in models_list:
-
+            if model._meta.auto_created:
+                continue  # automatic intermediat models created by
+                          # ManyToManyField should not disable delete
             for f, m in model._meta.get_fields_with_model():
 
                 # Refuse nullable CharFields, but don't trigger on
@@ -422,7 +424,7 @@ class Kernel(object):
     def run_callback(self, request, thread_id, button_id):
         """
         Return an existing (pending) callback.
-        This is called from `lino.ui.views.Callbacks`.
+        This is called from `lino.core.views.Callbacks`.
         """
         # logger.info("20131212 get_callback %s %s", thread_id, button_id)
 
@@ -706,6 +708,6 @@ class Kernel(object):
                 try:
                     symlink(source, target)
                 except OSError as e:
-                    raise OSError(
-                        "Failed to create symlink %s -> %s : %s",
-                        target, source, e)
+                    msg = "Failed to symlink {0} to {1} : {2}"
+                    msg = msg.format(source, target, e)
+                    raise OSError(msg)
