@@ -38,6 +38,7 @@ from lino import mixins
 from lino.utils import join_elems
 from lino.utils.xmlgen.html import E
 from lino.modlib.contacts.utils import parse_name
+from lino.modlib.users.mixins import UserAuthored
 
 
 config = settings.SITE.plugins.courses
@@ -441,7 +442,8 @@ class Course(cal.Reservation):
 
     @property
     def events_by_course(self):
-        ct = dd.ContentType.objects.get_for_model(self.__class__)
+        ct = rt.modules.contenttypes.ContentType.objects.get_for_model(
+            self.__class__)
         return cal.Event.objects.filter(owner_type=ct, owner_id=self.id)
 
     @dd.requestfield(_("Requested"))
@@ -522,7 +524,7 @@ class Courses(dd.Table):
     order_by = ['name']
     auto_fit_column_widths = True
 
-    parameters = dd.ObservedPeriod(
+    parameters = mixins.ObservedPeriod(
         line=models.ForeignKey('courses.Line', blank=True, null=True),
         topic=models.ForeignKey('courses.Topic', blank=True, null=True),
         city=models.ForeignKey('countries.Place', blank=True, null=True),
@@ -710,7 +712,7 @@ class ConfirmedSubmitInsert(dd.SubmitInsert):
         ar.set_response(close_window=True)
 
 
-class Enrolment(mixins.UserAuthored, sales.Invoiceable):
+class Enrolment(UserAuthored, sales.Invoiceable):
 
     invoiceable_date_field = 'request_date'
     workflow_state_field = 'state'
@@ -855,7 +857,7 @@ class Enrolments(dd.Table):
     required = dd.required(user_level='manager')
     model = 'courses.Enrolment'
     stay_in_grid = True
-    parameters = dd.ObservedPeriod(
+    parameters = mixins.ObservedPeriod(
         author=dd.ForeignKey(
             settings.SITE.user_model, blank=True, null=True),
         state=EnrolmentStates.field(blank=True, null=True),
