@@ -27,12 +27,11 @@ from django.contrib.contenttypes.models import ContentType
 
 import lino
 from lino.core import constants
-from lino.ui import elems as ext_elems
-from lino.ui.render import HtmlRenderer
+from lino.core import elems as ext_elems
+from lino.core.renderer import HtmlRenderer
 
 from lino.ad import Plugin
 
-from lino import dd
 from lino.core import actions
 from lino.core import dbtables
 from lino.core import tables
@@ -277,7 +276,7 @@ class ExtRenderer(HtmlRenderer):
         rows) or two buttons :guilabel:`Show` and :guilabel:`Edit` if
         it has one row.
         
-        See also :doc:`/tickets/56`.
+        See also :srcref:`docs/tickets/56`.
 
         """
         if rr.get_total_count() == 0:
@@ -1243,7 +1242,7 @@ class ExtRenderer(HtmlRenderer):
         kw.update(ls_bbar_actions=self.toolbar(
             rh.actor.get_toolbar_actions(rh.actor.default_action.action)))
         kw.update(ls_grid_configs=[gc.data for gc in rh.actor.grid_configs])
-        kw.update(gc_name=ext_elems.DEFAULT_GC_NAME)
+        kw.update(gc_name=constants.DEFAULT_GC_NAME)
         #~ if action != rh.actor.default_action:
             #~ kw.update(action_name=action.name)
         #~ kw.update(content_type=rh.report.content_type)
