@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 """
-This is a Python dump created using Lino 1.6.17, Django 1.6.7, Python 2.7.4, Babel 1.3, Jinja 2.7.2, Sphinx 1.3a0, python-dateutil 2.1, OdfPy ODFPY/0.9.6, docutils 0.11, suds 0.4, PyYaml 3.10, Appy 0.9.0 (2014/06/23 22:15).
+This is a Python dump created using Lino 1.6.16, Django 1.6.5, Python 2.7.4, Babel 1.3, Jinja 2.7.3, Sphinx 1.3b3, python-dateutil 2.1, OdfPy ODFPY/0.9.6, docutils 0.11, suds 0.4, PyYaml 3.10, Appy 0.9.0 (2014/06/23 22:15).
 
 """
 from __future__ import unicode_literals
@@ -549,11 +549,11 @@ def create_users_user(id, modified, created, username, password, profile, initia
     kw.update(event_type_id=event_type_id)
     return users_User(**kw)
 
-def create_cal_recurrentevent(id, user_id, name, start_date, start_time, end_date, end_time, every_unit, every, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, event_type_id, description):
+def create_cal_recurrentevent(id, name, user_id, start_date, start_time, end_date, end_time, every_unit, every, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, event_type_id, description):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     if name is not None: kw.update(bv2kw('name',name))
+    kw.update(user_id=user_id)
     kw.update(start_date=start_date)
     kw.update(start_time=start_time)
     kw.update(end_date=end_date)
@@ -685,11 +685,11 @@ def create_system_textfieldtemplate(id, user_id, name, description, text):
     kw.update(text=text)
     return system_TextFieldTemplate(**kw)
 
-def create_tickets_project(id, user_id, ref, name, parent_id, type_id, description, srcref_url_template, changeset_url_template):
+def create_tickets_project(id, ref, user_id, name, parent_id, type_id, description, srcref_url_template, changeset_url_template):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(ref=ref)
+    kw.update(user_id=user_id)
     kw.update(name=name)
     kw.update(parent_id=parent_id)
     kw.update(type_id=type_id)
@@ -698,15 +698,15 @@ def create_tickets_project(id, user_id, ref, name, parent_id, type_id, descripti
     kw.update(changeset_url_template=changeset_url_template)
     return tickets_Project(**kw)
 
-def create_cal_event(id, user_id, modified, created, project_id, build_time, build_method, owner_type_id, owner_id, start_date, start_time, end_date, end_time, summary, description, access_class, sequence, auto_type, event_type_id, transparent, room_id, priority_id, state, assigned_to_id):
+def create_cal_event(id, modified, created, project_id, build_time, build_method, user_id, owner_type_id, owner_id, start_date, start_time, end_date, end_time, summary, description, access_class, sequence, auto_type, event_type_id, transparent, room_id, priority_id, state, assigned_to_id):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(modified=modified)
     kw.update(created=created)
     kw.update(project_id=project_id)
     kw.update(build_time=build_time)
     kw.update(build_method=build_method)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
@@ -737,13 +737,13 @@ def create_cal_guest(id, event_id, partner_id, role_id, state, remark):
     kw.update(remark=remark)
     return cal_Guest(**kw)
 
-def create_cal_task(id, user_id, modified, created, project_id, owner_type_id, owner_id, start_date, start_time, summary, description, access_class, sequence, auto_type, due_date, due_time, percent, state):
+def create_cal_task(id, modified, created, project_id, user_id, owner_type_id, owner_id, start_date, start_time, summary, description, access_class, sequence, auto_type, due_date, due_time, percent, state):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(modified=modified)
     kw.update(created=created)
     kw.update(project_id=project_id)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
@@ -760,13 +760,13 @@ def create_cal_task(id, user_id, modified, created, project_id, owner_type_id, o
     kw.update(state=state)
     return cal_Task(**kw)
 
-def create_excerpts_excerpt(id, user_id, project_id, build_time, build_method, owner_type_id, owner_id, company_id, contact_person_id, contact_role_id, excerpt_type_id, language):
+def create_excerpts_excerpt(id, project_id, build_time, build_method, user_id, owner_type_id, owner_id, company_id, contact_person_id, contact_role_id, excerpt_type_id, language):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(project_id=project_id)
     kw.update(build_time=build_time)
     kw.update(build_method=build_method)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
@@ -777,11 +777,11 @@ def create_excerpts_excerpt(id, user_id, project_id, build_time, build_method, o
     kw.update(language=language)
     return excerpts_Excerpt(**kw)
 
-def create_outbox_mail(id, user_id, project_id, owner_type_id, owner_id, date, subject, body, sent):
+def create_outbox_mail(id, project_id, user_id, owner_type_id, owner_id, date, subject, body, sent):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(project_id=project_id)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
@@ -846,12 +846,12 @@ def create_tickets_milestone(id, ref, project_id, expected, reached):
     kw.update(reached=reached)
     return tickets_Milestone(**kw)
 
-def create_tickets_ticket(id, user_id, modified, created, reported_for_id, fixed_for_id, assigned_to_id, project_id, summary, state, closed, description):
+def create_tickets_ticket(id, modified, created, user_id, reported_for_id, fixed_for_id, assigned_to_id, project_id, summary, state, closed, description):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(modified=modified)
     kw.update(created=created)
+    kw.update(user_id=user_id)
     kw.update(reported_for_id=reported_for_id)
     kw.update(fixed_for_id=fixed_for_id)
     kw.update(assigned_to_id=assigned_to_id)
@@ -862,14 +862,14 @@ def create_tickets_ticket(id, user_id, modified, created, reported_for_id, fixed
     kw.update(description=description)
     return tickets_Ticket(**kw)
 
-def create_blogs_entry(id, user_id, modified, created, build_time, build_method, owner_type_id, owner_id, language, type_id, title, body, ticket_id):
+def create_blogs_entry(id, modified, created, build_time, build_method, user_id, owner_type_id, owner_id, language, type_id, title, body, ticket_id):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(modified=modified)
     kw.update(created=created)
     kw.update(build_time=build_time)
     kw.update(build_method=build_method)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
@@ -911,12 +911,12 @@ def create_tickets_vote(id, ticket_id, partner_id, remark):
     kw.update(remark=remark)
     return tickets_Vote(**kw)
 
-def create_uploads_upload(id, user_id, file, mimetype, owner_type_id, owner_id, upload_area, type_id, description):
+def create_uploads_upload(id, file, mimetype, user_id, owner_type_id, owner_id, upload_area, type_id, description):
     kw = dict()
     kw.update(id=id)
-    kw.update(user_id=user_id)
     kw.update(file=file)
     kw.update(mimetype=mimetype)
+    kw.update(user_id=user_id)
     owner_type_id = new_content_type_id(owner_type_id)
     kw.update(owner_type_id=owner_type_id)
     kw.update(owner_id=owner_id)
