@@ -15,7 +15,7 @@ from __future__ import unicode_literals
 
 SETUP_INFO = dict(
     name='lino',
-    version='1.6.16',
+    version='1.6.17',
     install_requires=[
         'django<1.7', 'Sphinx',
         'atelier', 'unipath', 'python_dateutil',
@@ -232,15 +232,10 @@ lino.test_apps.properties
 lino.test_apps.example
 lino.test_apps.quantityfield
 lino.test_apps.20121124
-lino.test_apps.mti
 lino.test_apps.nomti
 lino.tests
 lino.tutorials
 lino.tutorials.mini
-lino.tutorials.lets1
-lino.tutorials.lets1.fixtures
-lino.tutorials.lets1.lets
-lino.ui
 lino.utils
 lino.utils.demonames
 lino.utils.mldbc
