@@ -3,17 +3,13 @@
 # License: BSD (see file COPYING for details)
 
 """:mod:`lino.utils` (the top-level module) contains a few often-used
-function for general use. There are also many Subpackages_ and
-Submodules_.
+function for general use. It has also many subpackages and submodules.
 
 This is a tested document. To test it, run::
 
   $ python setup.py test -s tests.DocsTests.test_utils
 
 
-
-.. toctree::
-
 .. autosummary::
    :toctree:
 
@@ -51,6 +47,7 @@ This is a tested document. To test it, run::
     ranges
     requests
     restify
+    sendchanges
     screenshots
     sqllog
     ssin
@@ -125,10 +122,10 @@ def join_words(*words):
 
 def join_elems(elems, sep=' '):
     """
-    Examples::
-    >>> join_elems([1,2,3])
+    Examples:
+    >>> join_elems([1, 2, 3])
     [1, ' ', 2, ' ', 3]
-    >>> join_elems([1,2,3],' / ')
+    >>> join_elems([1, 2, 3],' / ')
     [1, ' / ', 2, ' / ', 3]
     >>> join_elems([])
     []
@@ -370,7 +367,7 @@ class IncompleteDate:
         if a > b:
             return today.year - self.year - 1
         return today.year - self.year
-        
+
 
 #~ class Warning(Exception):
     #~ """
