@@ -1,16 +1,6 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2012-2013 Luc Saffre
-## This file is part of the Lino project.
-## Lino is free software; you can redistribute it and/or modify 
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## Lino is distributed in the hope that it will be useful, 
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-## GNU General Public License for more details.
-## You should have received a copy of the GNU General Public License
-## along with Lino; if not, see <http://www.gnu.org/licenses/>.
+# Copyright 2012-2013 Luc Saffre
+# License: BSD (see file COPYING for details)
 
 ur"""
 OdsReader uses odfpy to extract data from an .ods document 
@@ -24,7 +14,7 @@ Unlike Marco's reader this one doesn't store any data in memory,
 it just loops over the rows.
 
 OdsReader is used to import data from .ods files into a 
-Django database using a :mod:`north.dpy` fixture,
+Django database using a :ref:`dpy` fixture,
 but not limited to this usage.
 
 State : works for me, but very young and probably full of bugs.
@@ -52,14 +42,15 @@ Robin Rood from London
 
 """
 import logging
-#~ logging.basicConfig(level='DEBUG') # uncomment this when debugging
+# ~ logging.basicConfig(level='DEBUG') # uncomment this when debugging
 logger = logging.getLogger(__name__)
 
 import os
 
+
 def srcpath(filename):
-    return os.path.join(os.path.dirname(__file__),filename)
-    
+    return os.path.join(os.path.dirname(__file__), filename)
+
 from odf import opendocument
 from odf.table import Table, TableRow, TableCell
 from odf.text import P
@@ -68,6 +59,7 @@ from lino.utils import AttrDict
 
 
 class SimpleOdsReader(object):
+
     """
     Abstract base class. For each .ods file you are probably creating 
     a subclass of this.
@@ -76,32 +68,32 @@ class SimpleOdsReader(object):
     """
     The full path name of the .ods file to be read.
     """
-    
+
     headers = None
     """
     A list of unicode strings, one for each column in the file.
     The headers specified here must match exactly those found 
     in the .ods file.
     """
-    
-    def __init__(self,**kw):
-        for k,v in kw.items():
-            setattr(self,k,v)
-  
-    def cells2row(self,cells):
+
+    def __init__(self, **kw):
+        for k, v in kw.items():
+            setattr(self, k, v)
+
+    def cells2row(self, cells):
         """
         This will be called for each recognized data row and 
         may perform a conversion before yielding it.
         Subclasses may override this.
         """
         return cells
-        
+
     def rows(self):
         """
         Yields the data rows found in this .ods file.
         """
         doc = opendocument.load(self.filename)
-        logger.debug("Reading %s",self.filename)
+        logger.debug("Reading %s", self.filename)
         if self.column_names is None:
             self.column_names = self.headers
         assert len(self.column_names) == len(self.headers)
@@ -110,34 +102,36 @@ class SimpleOdsReader(object):
             headers_found = False
             for row in sheet.getElementsByType(TableRow):
                 cells = []
-                for i,cell in enumerate(row.getElementsByType(TableCell)):
-                  
+                for i, cell in enumerate(row.getElementsByType(TableCell)):
+
                     content = ''
                     for p in cell.getElementsByType(P):
                         for n in p.childNodes:
                             content += unicode(n.data)
                     content = content.strip()
                     repeat = cell.getAttribute("numbercolumnsrepeated")
-                    if repeat: 
+                    if repeat:
                         repeat = int(repeat)
                     else:
                         repeat = 1
                     for r in range(repeat):
                         cells.append(content)
-                        
+
                 #~ if len(cells):
-                if ''.join(cells).strip(): 
+                if ''.join(cells).strip():
                     if headers_found:
                         yield self.cells2row(cells)
                     elif cells == self.headers:
                         headers_found = True
                     else:
-                        logger.debug("Unrecognized row %s",cells)
+                        logger.debug("Unrecognized row %s", cells)
             if not headers_found:
-                logger.debug("No data in %s.%s",self.filename,sheet_name)
-        logger.debug("Done reading %s",self.filename)
-        
+                logger.debug("No data in %s.%s", self.filename, sheet_name)
+        logger.debug("Done reading %s", self.filename)
+
+
 class OdsReader(SimpleOdsReader):
+
     """
     Like :class:`SimpleOdsReader`, but each row is converted to 
     an :class:`lino.utils.AttrDict`. This requires you to specifiy, 
@@ -147,9 +141,10 @@ class OdsReader(SimpleOdsReader):
     
     """
     column_names = None
-    def cells2row(self,cells):
+
+    def cells2row(self, cells):
         d = {}
-        for i,cell in enumerate(cells):
+        for i, cell in enumerate(cells):
             name = self.column_names[i]
             if name:
                 d[name] = cell
@@ -161,12 +156,11 @@ class OdsReader(SimpleOdsReader):
             i += 1
         #~ logger.info("20121122 cells2row %s -> %s",cells,d)
         return AttrDict(d)
-        
-            
+
+
 def _test():
     import doctest
     doctest.testmod()
 
 if __name__ == "__main__":
     _test()
-
