@@ -60,9 +60,6 @@ class DocsTests(LinoTestCase):
         docs/tested/test_i18n.rst
         """)
 
-    def test_ad(self):
-        self.run_simple_doctests("docs/dev/ad.rst")
-
     def test_dumpy(self):
         self.run_simple_doctests("docs/tutorials/dumpy.rst")
 
@@ -87,6 +84,12 @@ class DocsTests(LinoTestCase):
     def test_de_BE(self):
         self.run_django_manage_test('docs/tutorials/de_BE')
 
+    def test_sendchanges(self):
+        self.run_django_manage_test('docs/tutorials/sendchanges')
+
+    def test_mti(self):
+        self.run_django_manage_test('docs/tutorials/mti')
+
     def test_auto_create(self):
         self.run_django_manage_test('docs/tutorials/auto_create')
     
@@ -98,6 +101,9 @@ class DocsTests(LinoTestCase):
 
     def test_actors(self):
         self.run_django_manage_test('docs/tutorials/actors')
+
+    def test_watch(self):
+        self.run_django_manage_test('docs/tutorials/watch_tutorial')
     
     def test_vtables(self):
         self.run_django_manage_test('docs/tutorials/vtables')
@@ -114,6 +120,12 @@ class DocsTests(LinoTestCase):
     def test_hello(self):
         self.run_django_manage_test('docs/tutorials/hello')
 
+    def test_lets(self):
+        self.run_django_manage_test('docs/tutorials/lets')
+
+    def test_letsmti(self):
+        self.run_django_manage_test('docs/tutorials/letsmti')
+
     def test_mldbc(self):
         self.run_django_manage_test('docs/tutorials/mldbc')
 
@@ -127,6 +139,16 @@ class DocsTests(LinoTestCase):
         self.run_django_manage_test("docs/tested/integer_pk")
 
 
+class CoreTests(LinoTestCase):
+
+    def test_site(self):
+        self.run_simple_doctests('lino/core/site_def.py')
+
+    # TODO: implement pseudo tests for QuantityField
+    # def test_fields(self):
+    #     self.run_simple_doctests('lino/core/fields.py')
+
+
 class UtilsTests(LinoTestCase):
 
     def test_01(self):
@@ -170,9 +192,6 @@ class UtilsTests(LinoTestCase):
     def test_jsgen(self):
         self.run_simple_doctests('lino/utils/jsgen.py')
 
-    def test_site(self):
-        self.run_simple_doctests('lino/core/site_def.py')
-
     def test_format_date(self):
         self.run_simple_doctests('lino/utils/format_date.py')
 
@@ -217,8 +236,6 @@ class ProjectsTests(LinoTestCase):
 
 
 class Tutorials(LinoTestCase):
-    def test_lets(self):
-        self.run_django_manage_test("lino/tutorials/lets1")
 
     def test_mini(self):
         self.run_django_manage_test("lino/tutorials/mini")
